@@ -27,7 +27,7 @@ import random
 import logging
 import os
 import re
-import snscrape.base
+import umbraSnscrpe.base
 import string
 import time
 import typing
@@ -40,7 +40,7 @@ _globalGuestTokenManager = None
 
 
 @dataclasses.dataclass
-class Tweet(snscrape.base.Item):
+class Tweet(umbraSnscrpe.base.Item):
 	url: str
 	date: datetime.datetime
 	content: str
@@ -69,9 +69,9 @@ class Tweet(snscrape.base.Item):
 	hashtags: typing.Optional[typing.List[str]] = None
 	cashtags: typing.Optional[typing.List[str]] = None
 
-	username = snscrape.base._DeprecatedProperty('username', lambda self: self.user.username, 'user.username')
-	outlinksss = snscrape.base._DeprecatedProperty('outlinksss', lambda self: ' '.join(self.outlinks) if self.outlinks else '', 'outlinks')
-	tcooutlinksss = snscrape.base._DeprecatedProperty('tcooutlinksss', lambda self: ' '.join(self.tcooutlinks) if self.tcooutlinks else '', 'tcooutlinks')
+	username = umbraSnscrpe.base._DeprecatedProperty('username', lambda self: self.user.username, 'user.username')
+	outlinksss = umbraSnscrpe.base._DeprecatedProperty('outlinksss', lambda self: ' '.join(self.outlinks) if self.outlinks else '', 'outlinks')
+	tcooutlinksss = umbraSnscrpe.base._DeprecatedProperty('tcooutlinksss', lambda self: ' '.join(self.tcooutlinks) if self.tcooutlinks else '', 'tcooutlinks')
 
 	def __str__(self):
 		return self.url
@@ -132,7 +132,7 @@ class Place:
 
 
 @dataclasses.dataclass
-class User(snscrape.base.Entity):
+class User(umbraSnscrpe.base.Entity):
 	# Most fields can be None if they're not known.
 
 	username: str
@@ -174,7 +174,7 @@ class UserLabel:
 
 
 @dataclasses.dataclass
-class Trend(snscrape.base.Item):
+class Trend(umbraSnscrpe.base.Item):
 	name: str
 	domainContext: str
 	metaDescription: typing.Optional[str] = None
@@ -220,7 +220,7 @@ class _CLIGuestTokenManager(GuestTokenManager):
 			# This should be ${HOME}/.cache, but the HOME environment variable may not exist on non-POSIX-compliant systems.
 			# On POSIX-compliant systems, the XDG Base Directory specification is followed exactly since ~ expands to $HOME if it is present.
 			cacheHome = os.path.join(os.path.expanduser('~'), '.cache')
-		dir = os.path.join(cacheHome, 'snscrape')
+		dir = os.path.join(cacheHome, 'umbraSnscrpe')
 		if not os.path.isdir(dir):
 			# os.makedirs does not apply mode recursively anymore. https://bugs.python.org/issue42367
 			# This ensures that the XDG_CACHE_HOME is created with the right permissions.
@@ -268,7 +268,7 @@ class _CLIGuestTokenManager(GuestTokenManager):
 			os.remove(self._file)
 
 
-class _TwitterAPIScraper(snscrape.base.Scraper):
+class _TwitterAPIScraper(umbraSnscrpe.base.Scraper):
 	def __init__(self, baseUrl, guestTokenManager = None, **kwargs):
 		super().__init__(**kwargs)
 		self._baseUrl = baseUrl
@@ -312,7 +312,7 @@ class _TwitterAPIScraper(snscrape.base.Scraper):
 				r = self._post('https://api.twitter.com/1.1/guest/activate.json', data = b'', headers = self._apiHeaders, responseOkCallback = self._check_guest_token_response)
 				o = r.json()
 				if not o.get('guest_token'):
-					raise snscrape.base.ScraperError('Unable to retrieve guest token')
+					raise umbraSnscrpe.base.ScraperError('Unable to retrieve guest token')
 				self._guestTokenManager.token = o['guest_token']
 			assert self._guestTokenManager.token
 		_logger.debug(f'Using guest token {self._guestTokenManager.token}')
@@ -341,7 +341,7 @@ class _TwitterAPIScraper(snscrape.base.Scraper):
 		try:
 			obj = r.json()
 		except json.JSONDecodeError as e:
-			raise snscrape.base.ScraperException('Received invalid JSON from Twitter') from e
+			raise umbraSnscrpe.base.ScraperException('Received invalid JSON from Twitter') from e
 		return obj
 
 	def _iter_api_data(self, endpoint, params, paginationParams = None, cursor = None, direction = _ScrollDirection.BOTTOM):
@@ -467,7 +467,7 @@ class _TwitterAPIScraper(snscrape.base.Scraper):
 				return
 			tweet = obj['globalObjects']['tweets'][entry['item']['content']['tombstone']['tweet']['id']]
 		else:
-			raise snscrape.base.ScraperException(f'Unable to handle entry {entryId!r}')
+			raise umbraSnscrpe.base.ScraperException(f'Unable to handle entry {entryId!r}')
 		yield self._tweet_to_tweet(tweet, obj)
 
 	def _tweet_to_tweet(self, tweet, obj):
@@ -691,7 +691,7 @@ class TwitterSearchScraper(_TwitterAPIScraper):
 	def cli_setup_parser(cls, subparser):
 		subparser.add_argument('--cursor', metavar = 'CURSOR')
 		subparser.add_argument('--top', action = 'store_true', default = False, help = 'Enable fetching top tweets instead of live/chronological')
-		subparser.add_argument('query', type = snscrape.base.nonempty_string('query'), help = 'A Twitter search string')
+		subparser.add_argument('query', type = umbraSnscrpe.base.nonempty_string('query'), help = 'A Twitter search string')
 
 	@classmethod
 	def cli_from_args(cls, args):
@@ -772,7 +772,7 @@ class TwitterSearchScraperPeopple(_TwitterAPIScraper):
 	def cli_setup_parser(cls, subparser):
 		subparser.add_argument('--cursor', metavar = 'CURSOR')
 		subparser.add_argument('--top', action = 'store_true', default = False, help = 'Enable fetching top tweets instead of live/chronological')
-		subparser.add_argument('query', type = snscrape.base.nonempty_string('query'), help = 'A Twitter search string')
+		subparser.add_argument('query', type = umbraSnscrpe.base.nonempty_string('query'), help = 'A Twitter search string')
 
 	@classmethod
 	def cli_from_args(cls, args):
@@ -915,7 +915,7 @@ class TwitterHashtagScraper(TwitterSearchScraper):
 
 	@classmethod
 	def cli_setup_parser(cls, subparser):
-		subparser.add_argument('hashtag', type = snscrape.base.nonempty_string('hashtag'), help = 'A Twitter hashtag (without #)')
+		subparser.add_argument('hashtag', type = umbraSnscrpe.base.nonempty_string('hashtag'), help = 'A Twitter hashtag (without #)')
 
 	@classmethod
 	def cli_from_args(cls, args):
@@ -1015,7 +1015,7 @@ class TwitterListPostsScraper(TwitterSearchScraper):
 
 	@classmethod
 	def cli_setup_parser(cls, subparser):
-		subparser.add_argument('list', type = snscrape.base.nonempty_string('list'), help = 'A Twitter list ID or a string of the form "username/listname" (replace spaces with dashes)')
+		subparser.add_argument('list', type = umbraSnscrpe.base.nonempty_string('list'), help = 'A Twitter list ID or a string of the form "username/listname" (replace spaces with dashes)')
 
 	@classmethod
 	def cli_from_args(cls, args):
