@@ -9,7 +9,7 @@ import itertools
 import json
 import logging
 import re
-import src.base
+import umbraSnscrpe.base
 import typing
 import urllib.parse
 try:
@@ -39,7 +39,7 @@ _datePattern = re.compile(r'^(?P<date>today'
 
 
 @dataclasses.dataclass
-class VKontaktePost(src.base.Item):
+class VKontaktePost(umbraSnscrpe.base.Item):
 	url: str
 	date: typing.Optional[typing.Union[datetime.datetime, datetime.date]]
 	content: str
@@ -75,29 +75,29 @@ class Video:
 
 
 @dataclasses.dataclass
-class User(src.base.Entity):
+class User(umbraSnscrpe.base.Entity):
 	username: str
 	name: str
 	verified: bool
 	description: typing.Optional[str] = None
 	websites: typing.Optional[typing.List[str]] = None
-	followers: typing.Optional[src.base.IntWithGranularity] = None
-	posts: typing.Optional[src.base.IntWithGranularity] = None
-	photos: typing.Optional[src.base.IntWithGranularity] = None
-	tags: typing.Optional[src.base.IntWithGranularity] = None
-	following: typing.Optional[src.base.IntWithGranularity] = None
+	followers: typing.Optional[umbraSnscrpe.base.IntWithGranularity] = None
+	posts: typing.Optional[umbraSnscrpe.base.IntWithGranularity] = None
+	photos: typing.Optional[umbraSnscrpe.base.IntWithGranularity] = None
+	tags: typing.Optional[umbraSnscrpe.base.IntWithGranularity] = None
+	following: typing.Optional[umbraSnscrpe.base.IntWithGranularity] = None
 
-	followersGranularity = src.base._DeprecatedProperty('followersGranularity', lambda self: self.followers.granularity, 'followers.granularity')
-	postsGranularity = src.base._DeprecatedProperty('postsGranularity', lambda self: self.posts.granularity, 'posts.granularity')
-	photosGranularity = src.base._DeprecatedProperty('photosGranularity', lambda self: self.photos.granularity, 'photos.granularity')
-	tagsGranularity = src.base._DeprecatedProperty('tagsGranularity', lambda self: self.tags.granularity, 'tags.granularity')
-	followingGranularity = src.base._DeprecatedProperty('followingGranularity', lambda self: self.following.granularity, 'following.granularity')
+	followersGranularity = umbraSnscrpe.base._DeprecatedProperty('followersGranularity', lambda self: self.followers.granularity, 'followers.granularity')
+	postsGranularity = umbraSnscrpe.base._DeprecatedProperty('postsGranularity', lambda self: self.posts.granularity, 'posts.granularity')
+	photosGranularity = umbraSnscrpe.base._DeprecatedProperty('photosGranularity', lambda self: self.photos.granularity, 'photos.granularity')
+	tagsGranularity = umbraSnscrpe.base._DeprecatedProperty('tagsGranularity', lambda self: self.tags.granularity, 'tags.granularity')
+	followingGranularity = umbraSnscrpe.base._DeprecatedProperty('followingGranularity', lambda self: self.following.granularity, 'following.granularity')
 
 	def __str__(self):
 		return f'https://vk.com/{self.username}'
 
 
-class VKontakteUserScraper(src.base.Scraper):
+class VKontakteUserScraper(umbraSnscrpe.base.Scraper):
 	name = 'vkontakte-user'
 
 	def __init__(self, username, **kwargs):
@@ -231,7 +231,7 @@ class VKontakteUserScraper(src.base.Scraper):
 			_logger.info('Retrieving initial data')
 			r = self._get(self._baseUrl, headers = self._headers)
 			if r.status_code not in (200, 404):
-				raise src.base.ScraperException(f'Got status code {r.status_code}')
+				raise umbraSnscrpe.base.ScraperException(f'Got status code {r.status_code}')
 			# VK sends windows-1251-encoded data, but Requests's decoding doesn't seem to work correctly and causes lxml to choke, so we need to pass the binary content and the encoding explicitly.
 			self._initialPage, self._initialPageSoup = r, bs4.BeautifulSoup(r.content, 'lxml', from_encoding = r.encoding)
 		return self._initialPage, self._initialPageSoup
@@ -291,10 +291,10 @@ class VKontakteUserScraper(src.base.Scraper):
 						if not geoPosts.startswith('<div id="post'):
 							if geoPosts == '"\\/blank.php?block=119910902"':
 								continue
-							raise src.base.ScraperException(f'Got an unknown response: {geoPosts[:200]!r}...')
+							raise umbraSnscrpe.base.ScraperException(f'Got an unknown response: {geoPosts[:200]!r}...')
 						yield from _process_soup(soup = bs4.BeautifulSoup(geoPosts, 'lxml'))
 					continue
-				raise src.base.ScraperException(f'Got an unknown response: {posts[:200]!r}...')
+				raise umbraSnscrpe.base.ScraperException(f'Got an unknown response: {posts[:200]!r}...')
 			lastWorkingOffset = offset
 			soup = bs4.BeautifulSoup(posts, 'lxml')
 			yield from _process_soup(soup)
@@ -309,7 +309,7 @@ class VKontakteUserScraper(src.base.Scraper):
 		  headers = headers
 		 )
 		if r.status_code != 200:
-			raise src.base.ScraperException(f'Got status code {r.status_code}')
+			raise umbraSnscrpe.base.ScraperException(f'Got status code {r.status_code}')
 		# Convert to JSON and read the HTML payload.  Note that this implicitly converts the data to a Python string (i.e., Unicode), away from a windows-1251-encoded bytes.
 		posts = r.json()['payload'][1][0]
 		return posts
@@ -366,22 +366,22 @@ class VKontakteUserScraper(src.base.Scraper):
 				if label in ('follower', 'post', 'photo', 'tag'):
 					label = f'{label}s'
 				if label in ('followers', 'posts', 'photos', 'tags'):
-					kwargs[label] = src.base.IntWithGranularity(count, granularity)
+					kwargs[label] = umbraSnscrpe.base.IntWithGranularity(count, granularity)
 
 		if (idolsDiv := soup.find('div', id = 'profile_idols')):
 			if (topDiv := idolsDiv.find('div', class_ = 'header_top')) and topDiv.find('span', class_ = 'header_label').text == 'Following':
-				kwargs['following'] = src.base.IntWithGranularity(*parse_num(topDiv.find('span', class_ ='header_count').text))
+				kwargs['following'] = umbraSnscrpe.base.IntWithGranularity(*parse_num(topDiv.find('span', class_ ='header_count').text))
 
 		# On public pages, this is where followers are listed
 		if (followersDiv := soup.find('div', id = 'public_followers')):
 			if (topDiv := followersDiv.find('div', class_ = 'header_top')) and topDiv.find('span', class_ = 'header_label').text == 'Followers':
-				kwargs['followers'] = src.base.IntWithGranularity(*parse_num(topDiv.find('span', class_ ='header_count').text))
+				kwargs['followers'] = umbraSnscrpe.base.IntWithGranularity(*parse_num(topDiv.find('span', class_ ='header_count').text))
 
 		return User(**kwargs)
 
 	@classmethod
 	def _cli_setup_parser(cls, subparser):
-		subparser.add_argument('username', type = src.base.nonempty_string('username'), help ='A VK username')
+		subparser.add_argument('username', type = umbraSnscrpe.base.nonempty_string('username'), help ='A VK username')
 
 	@classmethod
 	def _cli_from_args(cls, args):
